public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: "duntan" <dun.tan@intel.com>
To: devel@edk2.groups.io
Cc: Ray Ni <ray.ni@intel.com>, Laszlo Ersek <lersek@redhat.com>,
	Rahul Kumar <rahul1.kumar@intel.com>,
	Gerd Hoffmann <kraxel@redhat.com>
Subject: [edk2-devel] [PATCH] UefiCpuPkg: change name of gMpInformationHobGuid2
Date: Thu, 11 Jan 2024 17:00:55 +0800	[thread overview]
Message-ID: <20240111090055.1721-1-dun.tan@intel.com> (raw)

Change name of gMpInformationHobGuid2 to
gMpInformation2HobGuid. It's to align with
the file name MpInformation2.h and the
structure name MP_INFORMATION2_HOB_DATA.

Signed-off-by: Dun Tan <dun.tan@intel.com>
Cc: Ray Ni <ray.ni@intel.com>
Cc: Laszlo Ersek <lersek@redhat.com>
Cc: Rahul Kumar <rahul1.kumar@intel.com>
Cc: Gerd Hoffmann <kraxel@redhat.com>
---
 UefiCpuPkg/CpuMpPei/CpuMpPei.c               | 8 ++++----
 UefiCpuPkg/CpuMpPei/CpuMpPei.inf             | 2 +-
 UefiCpuPkg/Include/Guid/MpInformation2.h     | 2 +-
 UefiCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.c   | 6 +++---
 UefiCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.inf | 2 +-
 UefiCpuPkg/UefiCpuPkg.dec                    | 2 +-
 6 files changed, 11 insertions(+), 11 deletions(-)

diff --git a/UefiCpuPkg/CpuMpPei/CpuMpPei.inf b/UefiCpuPkg/CpuMpPei/CpuMpPei.inf
index 812fa179bd..9ab2623bd0 100644
--- a/UefiCpuPkg/CpuMpPei/CpuMpPei.inf
+++ b/UefiCpuPkg/CpuMpPei/CpuMpPei.inf
@@ -50,7 +50,7 @@
 
 [Guids]
   gEdkiiMigratedFvInfoGuid                                             ## SOMETIMES_CONSUMES     ## HOB
-  gMpInformationHobGuid2                        ## PRODUCES
+  gMpInformation2HobGuid                        ## PRODUCES
 
 [Ppis]
   gEfiPeiMpServicesPpiGuid                      ## PRODUCES
diff --git a/UefiCpuPkg/Include/Guid/MpInformation2.h b/UefiCpuPkg/Include/Guid/MpInformation2.h
index 43185a4b01..2d9266f061 100644
--- a/UefiCpuPkg/Include/Guid/MpInformation2.h
+++ b/UefiCpuPkg/Include/Guid/MpInformation2.h
@@ -53,6 +53,6 @@ typedef struct {
 #define GET_MP_INFORMATION_ENTRY(MpInfoHobData, Index) \
     (MP_INFORMATION2_ENTRY *)((UINTN)&((MP_INFORMATION2_HOB_DATA *)(MpInfoHobData))->Entry + (MpInfoHobData)->EntrySize * Index)
 
-extern EFI_GUID  gMpInformationHobGuid2;
+extern EFI_GUID  gMpInformation2HobGuid;
 
 #endif
diff --git a/UefiCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.c b/UefiCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.c
index 9b230772cb..cd394826ff 100644
--- a/UefiCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.c
+++ b/UefiCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.c
@@ -776,7 +776,7 @@ GetMpInformation (
   HobIndex              = 0;
   HobCount              = 0;
 
-  FirstMpInfo2Hob = GetFirstGuidHob (&gMpInformationHobGuid2);
+  FirstMpInfo2Hob = GetFirstGuidHob (&gMpInformation2HobGuid);
   ASSERT (FirstMpInfo2Hob != NULL);
   GuidHob = FirstMpInfo2Hob;
   while (GuidHob != NULL) {
@@ -792,7 +792,7 @@ GetMpInformation (
 
     HobCount++;
     *NumberOfCpus += MpInformation2HobData->NumberOfProcessors;
-    GuidHob        = GetNextGuidHob (&gMpInformationHobGuid2, GET_NEXT_HOB (GuidHob));
+    GuidHob        = GetNextGuidHob (&gMpInformation2HobGuid, GET_NEXT_HOB (GuidHob));
   }
 
   ASSERT (*NumberOfCpus <= PcdGet32 (PcdCpuMaxLogicalProcessorNumber));
@@ -820,7 +820,7 @@ GetMpInformation (
   GuidHob = FirstMpInfo2Hob;
   while (HobIndex < HobCount) {
     MpInfo2Hobs[HobIndex++] = GET_GUID_HOB_DATA (GuidHob);
-    GuidHob                 = GetNextGuidHob (&gMpInformationHobGuid2, GET_NEXT_HOB (GuidHob));
+    GuidHob                 = GetNextGuidHob (&gMpInformation2HobGuid, GET_NEXT_HOB (GuidHob));
   }
 
   ProcessorInfo = (EFI_PROCESSOR_INFORMATION *)AllocatePool (sizeof (EFI_PROCESSOR_INFORMATION) * (*MaxNumberOfCpus));
diff --git a/UefiCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.inf b/UefiCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.inf
index 793220aba3..a018954ed7 100644
--- a/UefiCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.inf
+++ b/UefiCpuPkg/PiSmmCpuDxeSmm/PiSmmCpuDxeSmm.inf
@@ -120,7 +120,7 @@
   gEdkiiPiSmmMemoryAttributesTableGuid     ## CONSUMES ## SystemTable
   gEfiMemoryAttributesTableGuid            ## CONSUMES ## SystemTable
   gSmmBaseHobGuid                          ## CONSUMES
-  gMpInformationHobGuid2                   ## CONSUMES # Assume the HOB must has been created
+  gMpInformation2HobGuid                   ## CONSUMES # Assume the HOB must has been created
 
 [FeaturePcd]
   gUefiCpuPkgTokenSpaceGuid.PcdCpuSmmDebug                         ## CONSUMES
diff --git a/UefiCpuPkg/UefiCpuPkg.dec b/UefiCpuPkg/UefiCpuPkg.dec
index cc785a3222..571b59b36f 100644
--- a/UefiCpuPkg/UefiCpuPkg.dec
+++ b/UefiCpuPkg/UefiCpuPkg.dec
@@ -89,7 +89,7 @@
   gSmmBaseHobGuid      = { 0xc2217ba7, 0x03bb, 0x4f63, {0xa6, 0x47, 0x7c, 0x25, 0xc5, 0xfc, 0x9d, 0x73 }}
 
   ## Include/Guid/MpInformation2.h
-  gMpInformationHobGuid2         = { 0x417a7f64, 0xf4e9, 0x4b32, {0x84, 0x6a, 0x5c, 0xc4, 0xd8, 0x62, 0x18, 0x79 }}
+  gMpInformation2HobGuid         = { 0x417a7f64, 0xf4e9, 0x4b32, {0x84, 0x6a, 0x5c, 0xc4, 0xd8, 0x62, 0x18, 0x79 }}
 
 [Protocols]
   ## Include/Protocol/SmmCpuService.h
diff --git a/UefiCpuPkg/CpuMpPei/CpuMpPei.c b/UefiCpuPkg/CpuMpPei/CpuMpPei.c
index 93919be94f..2ce4d6ab50 100644
--- a/UefiCpuPkg/CpuMpPei/CpuMpPei.c
+++ b/UefiCpuPkg/CpuMpPei/CpuMpPei.c
@@ -566,7 +566,7 @@ GetProcessorCoreType (
 }
 
 /**
-  Create gMpInformationHobGuid2.
+  Create gMpInformation2HobGuid.
 **/
 VOID
 BuildMpInformationHob (
@@ -618,13 +618,13 @@ BuildMpInformationHob (
   //
   // Create MP_INFORMATION2_HOB. when the max HobLength 0xFFF8 is not enough, there
   // will be a MP_INFORMATION2_HOB series in the HOB list.
   // In the HOB list, there is a gMpInformationHobGuid2 with 0 value NumberOfProcessors
   // fields to indicate it's the last MP_INFORMATION2_HOB.
   //
   while (NumberOfProcessorsInHob != 0) {
     NumberOfProcessorsInHob = MIN (NumberOfProcessors - ProcessorIndex, MaxProcessorsPerHob);
     MpInformation2HobData   = BuildGuidHob (
-                                &gMpInformationHobGuid2,
+                                &gMpInformation2HobGuid,
                                 sizeof (MP_INFORMATION2_HOB_DATA) + sizeof (MP_INFORMATION2_ENTRY) * NumberOfProcessorsInHob
                                 );
     ASSERT (MpInformation2HobData != NULL);
@@ -744,7 +744,7 @@ InitializeCpuMpWorker (
   ASSERT_EFI_ERROR (Status);
 
   //
-  // Create gMpInformationHobGuid2
+  // Create gMpInformation2HobGuid
   //
   BuildMpInformationHob ();
 
@@ -618,13 +618,13 @@ BuildMpInformationHob (
   // Create MP_INFORMATION2_HOB. when the max HobLength 0xFFF8 is not enough, there
   // will be a MP_INFORMATION2_HOB series in the HOB list.
-  // In the HOB list, there is a gMpInformationHobGuid2 with 0 value NumberOfProcessors
+  // In the HOB list, there is a gMpInformation2HobGuid with 0 value NumberOfProcessors
   // fields to indicate it's the last MP_INFORMATION2_HOB.
   //
-- 
2.31.1.windows.1



-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.
View/Reply Online (#113601): https://edk2.groups.io/g/devel/message/113601
Mute This Topic: https://groups.io/mt/103658826/7686176
Group Owner: devel+owner@edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub [rebecca@openfw.io]
-=-=-=-=-=-=-=-=-=-=-=-



             reply	other threads:[~2024-01-11  9:01 UTC|newest]

Thread overview: 3+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2024-01-11  9:00 duntan [this message]
2024-01-11  9:42 ` [edk2-devel] [PATCH] UefiCpuPkg: change name of gMpInformationHobGuid2 Laszlo Ersek
2024-01-12  8:54 ` Ni, Ray

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20240111090055.1721-1-dun.tan@intel.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox